@@ -1,7 +1,7 @@
 import enum
 
 from ..model import m_benchmark, m_score_dir
-from ._benchmarks import sLM_21, abx_LS, tde_17, abx_17, abx_LS_phoneme
+from ._benchmarks import sLM_21, abx_LS, tde_17, abx_17
 
 
 class BenchmarkList(str, enum.Enum):
@@ -28,5 +28,4 @@ class BenchmarkList(str, enum.Enum):
     abx_17 = abx_17.ABX17Benchmark, abx_17.ABX17Submission, None
     # TODO: implement score_dir, leaderboard & verification
     tde_17 = tde_17.TDE17Benchmark, tde_17.TDE17Submission, None
-    # TODO: implement score_dir, leaderboard & verification
-    abx_LS_phoneme = abx_LS_phoneme.AbxLSRobBenchmark, abx_LS_phoneme.AbxLSRobSubmission, None
+
